# ezkfg

Easy Configuration

## Installation

```bash
pip install ezkfg
```

## Usage

```python
import ezkfg
```

## Acknowledgements

This project is inspired by the [addict](https://github.com/mewwts/addict) and [mmdetection](https://github.com/open-mmlab/mmdetection).
